==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetNotEvaluatedInteractionsAuditor.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SP MUETRA LA LISTA DE EVALUACIONES PENDIENTES PARA UN AUDITOR
CREATE PROCEDURE [dbo].[GetNotEvaluatedInteractionsAuditor] (
	@Instance Varchar(50) = NULL, 
	@UserId Varchar(50) = NULL,
	@IdCampaigns VARCHAR(MAX) = NULL,
	@IdAgents Varchar(MAX) = NULL,
	@EvaluationPlans Varchar(MAX) = NULL,
	@InteractionTypes Varchar(100) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
 	@EvaluationDateTo   VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationStatus BIT = 1,
 	@InteractionIds     VARCHAR(MAX) = NULL,
	@ContactAddress VARCHAR(300) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''

	-- IDENTIFICAMOS EL ROL DEL USUARIO
	SELECT @USER_ROLE = U.[Role]
		FROM [dbo].[User] U (NOLOCK)
		WHERE U.[VCC] = @Instance
			AND U.[ID] = @UserId

	-- EMULAMOS UNA NUEVA TABLA EN BASE A AuditorEvaluationPlan DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	SET @SQL_SELECT_1 += '
		WITH CTE AS (
			SELECT AEP.[Instance], 
					AEP.[IdEvaluationPlan], 
					AEP.[IdInteraction], 
					AEP.[IdAuditor], 
					AEP.[Score], 
					IEP.[AgentName],
					AEP.[LastModifiedDate],
					RN = ROW_NUMBER() OVER(PARTITION BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction] ORDER BY AEP.[LastModifiedDate] DESC)
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance] 
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[IdAgent] = AEP.[IdAgent]
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0 
				AND AEP.[IdAuditor] <> ''SPEECH''
				AND AEP.[StatusDescription] NOT IN(''INVALID'') '

	IF @USER_ROLE = 'quality_auditor' 
	BEGIN
		SET @SQL_SELECT_1 += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @SQL_SELECT_1 += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @SQL_SELECT_1 += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @SQL_SELECT_1 += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @SQL_SELECT_1 += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @SQL_SELECT_1 += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'

	SET @SQL_SELECT_1 += '
		),
		CLEANED_CTE AS (
			SELECT C.[Instance], 
					C.[IdEvaluationPlan], 
					C.[IdInteraction], 
					C.[IdAuditor], 
					C.[Score], 
					C.[AgentName],
					C.[LastModifiedDate]
			FROM [CTE] C
			WHERE C.[RN] = 1
		) '
	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	
	-- ARMAMOS EL SELECT PRINCIPAL PARA LA BUSQUEDA DE EVALUACIONES PENDIENTES DEL AUDITOR
	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '
	SET @SQL_SELECT_1 += '
				AEP.[IdInteraction]															''id'', 
				AEP.[IdCampaign]															''descriptionCampaign'',
				AEP.[IdAgent]																''idAgent'',
				AEP.[IdAgent]																''descriptionAgent'',
				AEP.[InteractionDate]														''dateIni'',
				AEP.[InteractionDateEnd]													''dateFin'',
				AEP.[InteractionDuration]													''interactionTime'',
				AEP.[Completed]																''evaluated'',
				AEP.[InteractionType]														''interactionType'',
				AEP.[ManagementResult]														''dispositionCode'',
				AEP.[ContactAddress]																''address'',
				AEP.[InteractionOrigin]														''origin'',
				AEP.[IdEvaluationPlan]														''idEvaluationPlan'',
				EP.[ProcessId]																''processId'',
				EP.[Description]															''descriptionEvaluationPlan'',
				EP.[DateFin]																''dateFinEvaluationPlan'', 
				EP.[Modality]																''evaluationPlanModality'',
				EP.[Evaluation_Mode]														''evaluationPlanEvaluationMode'',
				A.[ID]																		''idAuditor'', 
				A.[Description]																''descriptionAuditor'',
				ISNULL(U.[FirstName] + '' '', '''') + ISNULL(U.[LastName], '''')			''auditorName'',						-- NOMBRE DEL AUDITOR
				C.[AgentName]																''agentName'',							-- NOMBRE DEL AGENTE
				C.[IdAuditor]																''lastEvaluationEvaluator'', 
				C.[Score]																	''lastEvaluationScore'',
				AEP.[Status]																''status'',
				AEP.[StatusDescription]														''statusDescription'''

	SET @SQL_FROM += '
			FROM [AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = EP.Instance
					AND EP.[ID] = AEP.IdEvaluationPlan) 
			INNER JOIN CLEANED_CTE C (NOLOCK) 
				ON C.[Instance] = AEP.[Instance] 
					AND C.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND C.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[User] U (NOLOCK)
				ON U.[VCC] = AEP.[Instance]
					AND U.[ID] = AEP.[IdAuditor]
			LEFT JOIN [Auditor] A (NOLOCK) 
				ON (A.[ID] = AEP.[IdAuditor]) '

	SET @FILTERS_FIXED_PART = '
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0
				AND AEP.[StatusDescription] NOT IN(''INVALID'')
				AND EP.[Enabled] = 1 
				AND (
					(EP.[Evaluation_Mode] = ''X'' AND EP.[Status] = 8)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	-- AGREGAMOS EL FILTRO DE ESTADO
	IF @EvaluationStatus = 0
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 0 '
	END
	ELSE IF @EvaluationStatus = 1
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 1 '
	END

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'administrator' OR @USER_ROLE = 'quality_admin'
	BEGIN
		SET @FILTERS_FIXED_PART += ''
	END
	ELSE 
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	/*
	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	--IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	-- IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_EXCLUDING_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	*/
	IF (@EvaluationDateTo IS NOT NULL AND @EvaluationDateTo != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[DateFin] <= ''' + @EvaluationDateTo + '''  ';
	IF(@ContactAddress IS NOT NULL AND @ContactAddress <>'')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
       BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
       END

	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;

	--SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.1.0_database.tar.gz: database/mssql/procedures/GetNotEvaluatedInteractionsAuditor.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetNotEvaluatedInteractionsAuditor] (
	@Instance Varchar(50) = NULL, 
	@UserId Varchar(50) = NULL,
	@IdCampaigns VARCHAR(MAX) = NULL,
	@IdAgents Varchar(MAX) = NULL,
	@EvaluationPlans Varchar(MAX) = NULL,
	@InteractionTypes Varchar(100) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
 	@EvaluationPlanDateTo   VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationStatus BIT = 1,
 	@InteractionIds     VARCHAR(MAX) = NULL,
	@ContactAddress VARCHAR(300) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''

	-- IDENTIFICAMOS EL ROL DEL USUARIO
	SELECT @USER_ROLE = U.[Role]
		FROM [dbo].[User] U (NOLOCK)
		WHERE U.[VCC] = @Instance
			AND U.[ID] = @UserId

	-- EMULAMOS UNA NUEVA TABLA EN BASE A AuditorEvaluationPlan DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	SET @SQL_SELECT_1 += '
		WITH CTE AS (
			SELECT AEP.[Instance], 
					AEP.[IdEvaluationPlan], 
					AEP.[IdInteraction], 
					AEP.[IdAuditor], 
					AEP.[Score], 
					IEP.[AgentName],
					AEP.[LastModifiedDate],
					RN = ROW_NUMBER() OVER(PARTITION BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction] ORDER BY AEP.[LastModifiedDate] DESC)
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance] 
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[IdAgent] = AEP.[IdAgent]
			WHERE AEP.[Instance] = ''' + @Instance + ''' 
				AND AEP.[Completed] = 0 
				AND AEP.[IdAuditor] <> ''SPEECH''
				AND AEP.[StatusDescription] NOT IN(''INVALID'') '

	IF @USER_ROLE = 'quality_auditor' 
	BEGIN
		SET @SQL_SELECT_1 += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @SQL_SELECT_1 += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @SQL_SELECT_1 += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @SQL_SELECT_1 += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @SQL_SELECT_1 += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @SQL_SELECT_1 += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'

	SET @SQL_SELECT_1 += '
		),
		CLEANED_CTE AS (
			SELECT C.[Instance], 
					C.[IdEvaluationPlan], 
					C.[IdInteraction], 
					C.[IdAuditor], 
					C.[Score], 
					C.[AgentName],
					C.[LastModifiedDate]
			FROM [CTE] C
			WHERE C.[RN] = 1
		) '
	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	
	-- ARMAMOS EL SELECT PRINCIPAL PARA LA BUSQUEDA DE EVALUACIONES PENDIENTES DEL AUDITOR
	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '
	SET @SQL_SELECT_1 += '
				AEP.[IdInteraction]															''id'', 
				AEP.[IdCampaign]															''descriptionCampaign'',
				AEP.[IdAgent]																''idAgent'',
				AEP.[IdAgent]																''descriptionAgent'',
				AEP.[InteractionDate]														''dateIni'',
				AEP.[InteractionDateEnd]													''dateFin'',
				AEP.[InteractionDuration]													''interactionTime'',
				AEP.[Completed]																''evaluated'',
				AEP.[InteractionType]														''interactionType'',
				AEP.[ManagementResult]														''dispositionCode'',
				AEP.[ContactAddress]																''address'',
				AEP.[InteractionOrigin]														''origin'',
				AEP.[IdEvaluationPlan]														''idEvaluationPlan'',
				EP.[ProcessId]																''processId'',
				EP.[Description]															''descriptionEvaluationPlan'',
				EP.[DateFin]																''dateFinEvaluationPlan'', 
				EP.[Modality]																''evaluationPlanModality'',
				EP.[Evaluation_Mode]														''evaluationPlanEvaluationMode'',
				A.[ID]																		''idAuditor'', 
				A.[Description]																''descriptionAuditor'',
				ISNULL(U.[FirstName] + '' '', '''') + ISNULL(U.[LastName], '''')			''auditorName'',						-- NOMBRE DEL AUDITOR
				C.[AgentName]																''agentName'',							-- NOMBRE DEL AGENTE
				C.[IdAuditor]																''lastEvaluationEvaluator'', 
				C.[Score]																	''lastEvaluationScore'',
				AEP.[Status]																''status'',
				CASE
					WHEN EP.[DateFin] < CAST(GETDATE()  AS DATE)
					THEN 1
					ELSE 0
				END																			''isExpired'',
				AEP.[StatusDescription]														''statusDescription'''

	SET @SQL_FROM += '
			FROM [AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = EP.Instance
					AND EP.[ID] = AEP.IdEvaluationPlan) 
			INNER JOIN CLEANED_CTE C (NOLOCK) 
				ON C.[Instance] = AEP.[Instance] 
					AND C.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND C.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[User] U (NOLOCK)
				ON U.[VCC] = AEP.[Instance]
					AND U.[ID] = AEP.[IdAuditor]
			LEFT JOIN [Auditor] A (NOLOCK) 
				ON (A.[ID] = AEP.[IdAuditor]) '

	SET @FILTERS_FIXED_PART = '
			WHERE AEP.[Instance] = ''' + @Instance + '''
				AND AEP.[InteractionDate] >= ''' + @EvaluationDateFrom + '''
				AND AEP.[InteractionDate] <= ''' + @EvaluationDateTo + ''' 
				AND AEP.[Completed] = 0
				AND AEP.[StatusDescription] NOT IN(''INVALID'')
				AND EP.[Enabled] = 1 
				AND (
					(EP.[Evaluation_Mode] = ''X'' AND EP.[Status] = 8)
					OR
					(EP.[Evaluation_Mode] = ''M'')
				) '

	-- AGREGAMOS EL FILTRO DE ESTADO
	IF @EvaluationStatus = 0
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 0 '
	END
	ELSE IF @EvaluationStatus = 1
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 1 '
	END

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'administrator' OR @USER_ROLE = 'quality_admin'
	BEGIN
		SET @FILTERS_FIXED_PART += ''
	END
	ELSE 
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	AEP.[IdAuditor] = ''' + @UserId + ''' '
	END

	/*
	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';
	--IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	-- IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_EXCLUDING_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	*/
	IF (@EvaluationPlanDateTo IS NOT NULL AND @EvaluationPlanDateTo != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[DateFin] <= ''' + @EvaluationPlanDateTo + '''  ';
	IF(@ContactAddress IS NOT NULL AND @ContactAddress <>'')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
       BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
       END

	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;

	-- print @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)

 	SET NOCOUNT OFF
END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
